<?php
	// このファイルはGoogle Maps API v2用となっております。
	// ご利用の際には、このファイルをinputgmap.phpにリネームしてください。
	// （元のinputgmap.phpはinputgmap_v3.phpなどとして将来の為に保管しておいてください）

	require_once( dirname(__FILE__) . "/include/app.php.inc" );
	
	// 設定ファイルから規定値を読み込む
	// Site.Configより指定されたエントリ設定情報を取得する。
	$defaultLat = "35.681391";
	$defaultLng = "139.766103";
	$defaultZoom = "15";
	$gmapKey = "";
	$xmlDocSite = domxml_open_file( App::getSiteConfigFilePath() );
	$xpath = $xmlDocSite->xpath_new_context();

	$xmlGMapConfigArr = $xpath->xpath_eval( "/site/gmap" );
	if ( count($xmlGMapConfigArr->nodeset) > 0 )
	{
		$xmlGMapConfig = $xmlGMapConfigArr->nodeset[0];
		$gmapKey = nullString( $xmlGMapConfig->get_attribute("key") );
		$defaultLat = nullString( $xmlGMapConfig->get_attribute("lat"), $defaultLat );
		$defaultLng = nullString( $xmlGMapConfig->get_attribute("lng"), $defaultLng );
		$defaultZoom = nullString( $xmlGMapConfig->get_attribute("zoom"), $defaultZoom );
	}

	// 各パラメータの取得
	$lat = getGETParam( 'lat' , '' );
	$lng = getGETParam( 'lng', '' );
	$zoom = getGETParam( 'zoom', '' );
	$targetItemName = getGETParam( 'tname', '' );
	
	// latが数値でなかった場合は空にする
	if ( $lat !== '' and ! is_numeric( $lat ) )
	{
		$lat = '';
	}
	
	// lngが数値でなかった場合は空にする。
	if ( $lng !== '' and ! is_numeric( $lng ) )
	{
		$lng = '';
	}
	
	// zoomが数値でなかった場合は空にする。
	if ( $zoom !== '' and ! is_numeric( $zoom ) )
	{
		$zoom = '';
	}
	
	// latかlngが空だったら、規定値を入れる。
	if ( $lat === '' or $lng === '' )
	{
		$lat = $defaultLat;
		$lng = $defaultLng;
	}
	
	// zoomが空だったら、規定値を入れる。
	if ( $zoom === '' )
	{
		$zoom = $defaultZoom;
	}
	
	// targetItemNameパラメータの必須チェック
	if ( $targetItemName === '' )
	{
		die( 'Error : Bad request' );
	}
	
	$result = "{ 'lat' : $lat, 'lng' : $lng, 'zoom' : $zoom, 'targetItemName' : '$targetItemName' }";

?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
  <head>
	<meta http-equiv="content-type" content="text/html; charset=utf-8"/>
	<title>位置情報の入力</title>
	<style tyhpe="text/css">
	<!--
		form {
			padding : 0px;
			margin :0px;
		}
		
		body {
			margin :0px;
			padding :0px;
			margin-top : 20px;
		}
		
		#panelMain {
			width : 550px;
			height : 500px;
			margin-left : auto;
			margin-right : auto;
			margin-bottom : auto;
		}
		
		#panelMap {
			border-left : 1px solid #eeeeee;
			border-top : 1px solid #ddddff;
			border-right : 1px solid #888888;
			border-bottom : 1px solid #888888;
			/* border : 1px solid #88ddff; */
			background-color : #dddddd;
			padding : 24px;
		}
		
		#map {
			width: 500px; height: 300px;
		}
		
		#msg {
			padding:0.2em;
			background-color:#f0f0ff;
			color=red;
		}
		
		#results {
			font-size : 8pt;
			color : #3355ff;
			background-color : #ddeeff;
			padding : 0.5em;
		}
		
		#panelButtons {
			text-align : center;
			padding-top : 10px;
		}
		
		#panelButtons input {
			font-weight : bold;
			margin-left : 10px;
			padding : 0.5em 2em 0.5em 2em;
			background-color : #aabbcc
		}
		
	-->
	</style>
	<script src="http://maps.google.co.jp/maps?file=api&amp;v=2&amp;key=<?php print( $gmapKey ); ?>"
	  type="text/javascript"></script>
	  
	<script type="text/javascript">

	//<![CDATA[
	
	var map = null;
	var sightMarker = null;
	var geocoder = null;
	var geocodedLatLng = null;
	var result = <?php print $result; ?>; //{ "lat" : 35.681391, "lng" : 139.766103, "zoom" : 15, "targetItemName" : "location" };
	
	function load() {
		if (GBrowserIsCompatible()) {
			map = new GMap2(document.getElementById("map"));
			map.setCenter(new GLatLng(37.4419, -122.1419), 13);
			//map.addControl(new GSmallMapControl());
			map.addControl(new GLargeMapControl());
			map.addControl(new GMapTypeControl());
			
			geocoder = new GClientGeocoder();
			//showAddress( document.getElementById("address").value );
			
			// 照準画像を生成してセットする
			var sight = new GIcon();
			sight.image = "./manager.resources/sight.png";
			sight.iconSize = new GSize( 100, 100 );
			sight.iconAnchor = new GPoint( 49, 49 );
			sight.transparent = "./manager.resources/sight_b.png";
			sight.imageMap = new Array( 0,0, 1,0, 1,1, 0,1);
			
			sightMarker = new GMarker( map.getCenter(), sight );
			map.addOverlay( sightMarker );
			
			GEvent.addListener( map, "move", 
				function() {
					sightMarker.setPoint( map.getCenter() );
					showLatLng( map.getCenter() );
					showZoom( map.getZoom() );
					
					if ( ! map.getCenter().equals( geocodedLatLng ) )
					{
						setAddress( "" );
					}
					
					result.lat = map.getCenter().lat();
					result.lng = map.getCenter().lng();
					result.zoom = map.getZoom();
				}
			);
			
			GEvent.addListener( map, "click", 
				function(overlay, point) { 
					map.panTo( point );
				} 
			);
			
			map.setCenter( new GLatLng( result.lat, result.lng, false ), result.zoom );
		}
	}
	
	function showAddress(address) {
		if (geocoder) {
			geocoder.getLatLng(
				address,
				function(point) {
					if (!point) {
						document.getElementById("msg").innerHTML =address+"は見つかりませんでした";
					} else {
						geocodedLatLng = point;
						
						map.setCenter(point, 15);
						document.getElementById("msg").innerHTML = "";
						showLatLng( point );
						showZoom( map.getZoom() );
						//var marker = new GMarker(point);
						//map.addOverlay(marker);
					}
				}
			);
		}
	}
	
	function setAddress( newValue)
	{
		document.getElementById( "address" ).value = newValue;
	}
	
	function showLatLng( point )
	{
		document.getElementById( "LatLng" ).innerHTML = point; //"(" + point.lat() + "," + point.lng() + ")";
	}
	
	function showZoom( zoom )
	{
		document.getElementById( "zoom" ).innerHTML = zoom;
	}
	
	function cancelGMap()
	{
		window.close();
	}
	
	function applyGMap()
	{
		//alert( 'lat : ' + result.lat + ', lng : ' + result.lng + ', zoom : ' + result.zoom );
		window.opener.document.frmEntryEditor[ result.targetItemName + '_LAT' ].value = result.lat;
		window.opener.document.frmEntryEditor[ result.targetItemName + '_LNG' ].value = result.lng;
		window.opener.document.frmEntryEditor[ result.targetItemName + '_ZOOM' ].value = result.zoom;
		window.close();
   }

	//]]>
	</script>
  </head>
  <body onload="load()" onunload="GUnload()">
	<div id="panelMain">
		<div id="panelMap">
			<form onsubmit="return false;">
			住所を入力して場所を検索することができます。<br />
			<span style="font-size:0.7em">（入力例：「JR福井駅」「福井県鯖江市上鯖江1丁目」等）</span><br />
			<input type="text" id="address" name="address" size="60" value="" />
			<input type="button" value="検索" onclick="showAddress(this.form.address.value); return false;" /><br />
			<br />
			十字が示す位置をマウスで動かして位置を指定できます。<br />
			<span style="font-size:0.7em">（※地図が灰色表示の場合は画像の読込中です。しばらくお待ち下さい）</span>
			</form>
			<div id="msg"></div>
			<div id="map"></div>
			<div id="results">
			緯度・経度：<span id="LatLng"></span><br />
			縮尺：<span id="zoom"></span><br />
			</div>
		</div>
		<div id="panelButtons">
			<form onsubmit="return false;">
				<input type="button" value="キャンセル" onclick="cancelGMap();return false;" />
				<input type="button" value="この位置で決定" onclick="applyGMap();return false;" />
			</form>
		</div>
	</div>
  </body>
</html>